MeSendPushAction class
A tray notification CTA button parsed from title{n} / url{n} /
action{n} push data.
Constructors
- MeSendPushAction({required String slot, required String title, String? actionId, String? url})
-
const
Properties
- actionId → String?
-
Value of
action{n}(for examplePUSHAPP_BUY), when the payload sets it.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slot → String
-
Slot key (
action1,action2, …), reported asctaIdwhen tracking.final - title → String
-
Button label shown in the tray.
final
- url → String?
-
URL opened when the button is tapped.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited