NotificationConfig class

Implementers

Constructors

NotificationConfig({required String title, required String subtitle, String? imageUrl, Color? backgroundColor, String? backgroundImageUrl, double? titleFontSize, double? subtitleFontSize, Color? titleColor, Color? subtitleColor, List<NotificationButton>? buttons})
NotificationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor Color?
final
backgroundImageUrl String?
final
buttons List<NotificationButton>?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String
final
subtitleColor Color?
final
subtitleFontSize double?
final
title String
final
titleColor Color?
final
titleFontSize double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited