MeSendDataPushPayload class
Parsed MeSend FCM data payload (no notification block required).
Constructors
-
MeSendDataPushPayload({String? id, String? type, String? category, String? title, String? body, String? imageUrl, String? clickToken, List<
MeSendPushAction> actions = const <MeSendPushAction>[], Map<String, dynamic> rawData = const {}}) -
const
- MeSendDataPushPayload.fromRemoteMessage(RemoteMessage message)
-
factory
Properties
-
actions
→ List<
MeSendPushAction> -
final
- androidChannelId → String
-
no setter
- body → String?
-
final
- category → String?
-
final
- clickToken → String?
-
final
- displayBody → String
-
no setter
- displayTitle → String
-
no setter
- hasDisplayableContent → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- imageUrl → String?
-
final
-
rawData
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldShowTrayNotification → bool
-
Whether this push should appear in the system tray (vs in-app only).
no setter
- title → String?
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited