ScoreNotificationConfig class
- Inheritance
-
- Object
- NotificationConfig
- ScoreNotificationConfig
Constructors
-
ScoreNotificationConfig({required String title, required String subtitle, required String team1, required String team2, required String score1, required String score2, String? team1LogoUrl, String? team2LogoUrl, String? matchStatus, String? additionalInfo, Color? backgroundColor, List<
NotificationButton> ? buttons}) -
ScoreNotificationConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- additionalInfo → String?
-
final
- backgroundColor → Color?
-
finalinherited
- backgroundImageUrl → String?
-
finalinherited
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
finalinherited
- matchStatus → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score1 → String
-
final
- score2 → String
-
final
- subtitle → String
-
finalinherited
- subtitleColor → Color?
-
finalinherited
- subtitleFontSize → double?
-
finalinherited
- team1 → String
-
final
- team1LogoUrl → String?
-
final
- team2 → String
-
final
- team2LogoUrl → String?
-
final
- title → String
-
finalinherited
- titleColor → Color?
-
finalinherited
- titleFontSize → double?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited